@@ -1,13 +1,19 @@
 from time import time
 
+import django
 import sqlparse
 from django.core.management.commands.shell import Command  # noqa
-from django.db.backends import utils as db_backends_utils
+from django.db import connection
+
+if connection.vendor == "postgresql" and django.VERSION >= (3, 0, 0):
+    from django.db.backends.postgresql import base as base_module
+else:
+    from django.db.backends import utils as base_module
 
 # 'debugsqlshell' is the same as the 'shell'.
 
 
-class PrintQueryWrapper(db_backends_utils.CursorDebugWrapper):
+class PrintQueryWrapper(base_module.CursorDebugWrapper):
     def execute(self, sql, params=()):
         start_time = time()
         try:
@@ -20,4 +26,4 @@ class PrintQueryWrapper(db_backends_utils.CursorDebugWrapper):
             print("{} [{:.2f}ms]".format(formatted_sql, duration))
 
 
-db_backends_utils.CursorDebugWrapper = PrintQueryWrapper
+base_module.CursorDebugWrapper = PrintQueryWrapper
