@@ -1,13 +1,10 @@
-from __future__ import absolute_import, division, unicode_literals
-
 import cProfile
 import os
 from colorsys import hsv_to_rgb
 from pstats import Stats
 
-from django.utils import six
 from django.utils.html import format_html
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from debug_toolbar import settings as dt_settings
 from debug_toolbar.panels import Panel
@@ -15,7 +12,7 @@ from debug_toolbar.panels import Panel
 # Occasionally the disable method on the profiler is listed before
 # the actual view functions. This function call should be ignored as
 # it leads to an error within the tests.
-INVALID_PROFILER_FUNC = '_lsprof.Profiler'
+INVALID_PROFILER_FUNC = "_lsprof.Profiler"
 
 
 def contains_profiler(func_tuple):
@@ -23,7 +20,7 @@ def contains_profiler(func_tuple):
     the INVALID_PROFILE_FUNC in any string value of the tuple."""
     has_profiler = False
     for value in func_tuple:
-        if isinstance(value, six.string_types):
+        if isinstance(value, str):
             has_profiler |= INVALID_PROFILER_FUNC in value
     return has_profiler
 
@@ -40,9 +37,10 @@ class DjangoDebugToolbarStats(Stats):
         return self.__root
 
 
-class FunctionCall(object):
-    def __init__(self, statobj, func, depth=0, stats=None,
-                 id=0, parent_ids=[], hsv=(0, 0.5, 1)):
+class FunctionCall:
+    def __init__(
+        self, statobj, func, depth=0, stats=None, id=0, parent_ids=[], hsv=(0, 0.5, 1)
+    ):
         self.statobj = statobj
         self.func = func
         if stats:
@@ -59,24 +57,28 @@ class FunctionCall(object):
 
     def background(self):
         r, g, b = hsv_to_rgb(*self.hsv)
-        return 'rgb(%f%%,%f%%,%f%%)' % (r * 100, g * 100, b * 100)
+        return "rgb({:f}%,{:f}%,{:f}%)".format(r * 100, g * 100, b * 100)
 
     def func_std_string(self):  # match what old profile produced
         func_name = self.func
-        if func_name[:2] == ('~', 0):
+        if func_name[:2] == ("~", 0):
             # special case for built-in functions
             name = func_name[2]
-            if name.startswith('<') and name.endswith('>'):
-                return '{%s}' % name[1:-1]
+            if name.startswith("<") and name.endswith(">"):
+                return "{%s}" % name[1:-1]
             else:
                 return name
         else:
             file_name, line_num, method = self.func
-            idx = file_name.find('/site-packages/')
+            idx = file_name.find("/site-packages/")
             if idx > -1:
-                file_name = file_name[(idx + 14):]
+                file_name = file_name[(idx + 14) :]
 
-            file_path, file_name = file_name.rsplit(os.sep, 1)
+            split_path = file_name.rsplit(os.sep, 1)
+            if len(split_path) > 1:
+                file_path, file_name = file_name.rsplit(os.sep, 1)
+            else:
+                file_path = "<module>"
 
             return format_html(
                 '<span class="djdt-path">{0}/</span>'
@@ -86,7 +88,8 @@ class FunctionCall(object):
                 file_path,
                 file_name,
                 line_num,
-                method)
+                method,
+            )
 
     def subfuncs(self):
         i = 0
@@ -99,13 +102,15 @@ class FunctionCall(object):
                 s1 = 0
             else:
                 s1 = s * (stats[3] / self.stats[3])
-            yield FunctionCall(self.statobj,
-                               func,
-                               self.depth + 1,
-                               stats=stats,
-                               id=str(self.id) + '_' + str(i),
-                               parent_ids=self.parent_ids + [self.id],
-                               hsv=(h1, s1, 1))
+            yield FunctionCall(
+                self.statobj,
+                func,
+                self.depth + 1,
+                stats=stats,
+                id=str(self.id) + "_" + str(i),
+                parent_ids=self.parent_ids + [self.id],
+                hsv=(h1, s1, 1),
+            )
 
     def count(self):
         return self.stats[1]
@@ -141,14 +146,14 @@ class ProfilingPanel(Panel):
     """
     Panel that displays profiling information.
     """
+
     title = _("Profiling")
 
-    template = 'debug_toolbar/panels/profiling.html'
+    template = "debug_toolbar/panels/profiling.html"
 
-    def process_view(self, request, view_func, view_args, view_kwargs):
+    def process_request(self, request):
         self.profiler = cProfile.Profile()
-        args = (request,) + view_args
-        return self.profiler.runcall(view_func, *args, **view_kwargs)
+        return self.profiler.runcall(super().process_request, request)
 
     def add_node(self, func_list, func, max_depth, cum_time=0.1):
         func_list.append(func)
@@ -160,7 +165,7 @@ class ProfilingPanel(Panel):
                     self.add_node(func_list, subfunc, max_depth, cum_time=cum_time)
 
     def generate_stats(self, request, response):
-        if not hasattr(self, 'profiler'):
+        if not hasattr(self, "profiler"):
             return None
         # Could be delayed until the panel content is requested (perf. optim.)
         self.profiler.create_stats()
@@ -172,8 +177,10 @@ class ProfilingPanel(Panel):
         if root_func:
             root = FunctionCall(self.stats, root_func, depth=0)
             func_list = []
-            self.add_node(func_list,
-                          root,
-                          dt_settings.get_config()['PROFILER_MAX_DEPTH'],
-                          root.stats[3] / 8)
-            self.record_stats({'func_list': func_list})
+            self.add_node(
+                func_list,
+                root,
+                dt_settings.get_config()["PROFILER_MAX_DEPTH"],
+                root.stats[3] / 8,
+            )
+            self.record_stats({"func_list": func_list})
