@@ -15,8 +15,8 @@ class RedirectsPanel(Panel):
 
     def process_request(self, request):
         response = super().process_request(request)
-        if 300 <= int(response.status_code) < 400:
-            redirect_to = response.get("Location", None)
+        if 300 <= response.status_code < 400:
+            redirect_to = response.get("Location")
             if redirect_to:
                 status_line = "{} {}".format(
                     response.status_code, response.reason_phrase
