@@ -3,11 +3,16 @@ import json
 from threading import local
 from time import time
 
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 
 from debug_toolbar import settings as dt_settings
 from debug_toolbar.utils import get_stack, get_template_info, tidy_stacktrace
 
+try:
+    from psycopg2._json import Json as PostgresJson
+except ImportError:
+    PostgresJson = None
+
 
 class SQLQueryTriggered(Exception):
     """Thrown when template panel triggers a query"""
@@ -105,6 +110,8 @@ class NormalCursorWrapper:
         return [self._quote_expr(p) for p in params]
 
     def _decode(self, param):
+        if PostgresJson and isinstance(param, PostgresJson):
+            return param.dumps(param.adapted)
         # If a sequence type, decode each element separately
         if isinstance(param, (tuple, list)):
             return [self._decode(element) for element in param]
@@ -113,10 +120,10 @@ class NormalCursorWrapper:
         if isinstance(param, dict):
             return {key: self._decode(value) for key, value in param.items()}
 
-        # make sure datetime, date and time are converted to string by force_text
+        # make sure datetime, date and time are converted to string by force_str
         CONVERT_TYPES = (datetime.datetime, datetime.date, datetime.time)
         try:
-            return force_text(param, strings_only=not isinstance(param, CONVERT_TYPES))
+            return force_str(param, strings_only=not isinstance(param, CONVERT_TYPES))
         except UnicodeDecodeError:
             return "(encoded string)"
 
@@ -136,7 +143,6 @@ class NormalCursorWrapper:
                 _params = json.dumps(self._decode(params))
             except TypeError:
                 pass  # object not JSON serializable
-
             template_info = get_template_info()
 
             alias = getattr(self.db, "alias", "default")
