@@ -1,10 +1,9 @@
 from django.contrib.auth.models import User
 from django.db import IntegrityError, transaction
 from django.http import HttpResponse
-from django.test import TestCase
 from django.test.utils import override_settings
 
-from ..base import BaseTestCase
+from ..base import BaseTestCase, IntegrationTestCase
 from ..views import listcomp_view, regular_view
 
 
@@ -32,19 +31,17 @@ class ProfilingPanelTestCase(BaseTestCase):
         self.assertNotIn("regular_view", self.panel.content)
         self.panel.generate_stats(self.request, response)
         # ensure the panel renders correctly.
-        self.assertIn("regular_view", self.panel.content)
-        self.assertValidHTML(self.panel.content)
+        content = self.panel.content
+        self.assertIn("regular_view", content)
+        self.assertValidHTML(content)
 
     def test_listcomp_escaped(self):
         self._get_response = lambda request: listcomp_view(request)
         response = self.panel.process_request(self.request)
         self.panel.generate_stats(self.request, response)
-        self.assertNotIn(
-            '<span class="djdt-func"><listcomp></span>', self.panel.content
-        )
-        self.assertIn(
-            '<span class="djdt-func">&lt;listcomp&gt;</span>', self.panel.content
-        )
+        content = self.panel.content
+        self.assertNotIn('<span class="djdt-func"><listcomp></span>', content)
+        self.assertIn('<span class="djdt-func">&lt;listcomp&gt;</span>', content)
 
     def test_generate_stats_no_profiler(self):
         """
@@ -68,7 +65,7 @@ class ProfilingPanelTestCase(BaseTestCase):
 @override_settings(
     DEBUG=True, DEBUG_TOOLBAR_PANELS=["debug_toolbar.panels.profiling.ProfilingPanel"]
 )
-class ProfilingPanelIntegrationTestCase(TestCase):
+class ProfilingPanelIntegrationTestCase(IntegrationTestCase):
     def test_view_executed_once(self):
         self.assertEqual(User.objects.count(), 0)
 
