@@ -1,24 +1,31 @@
 import os
+import re
 import unittest
 
+import django
 import html5lib
 from django.contrib.staticfiles.testing import StaticLiveServerTestCase
 from django.core import signing
-from django.core.checks import Warning, run_checks
+from django.db import connection
 from django.http import HttpResponse
 from django.template.loader import get_template
-from django.test import RequestFactory, SimpleTestCase, TestCase
+from django.test import RequestFactory
 from django.test.utils import override_settings
 
+from debug_toolbar.forms import SignedDataForm
 from debug_toolbar.middleware import DebugToolbarMiddleware, show_toolbar
+from debug_toolbar.panels import Panel
 from debug_toolbar.toolbar import DebugToolbar
 
-from .base import BaseTestCase
+from .base import BaseTestCase, IntegrationTestCase
 from .views import regular_view
 
 try:
     from selenium import webdriver
     from selenium.common.exceptions import NoSuchElementException
+    from selenium.webdriver.common.by import By
+    from selenium.webdriver.firefox.options import Options
+    from selenium.webdriver.support import expected_conditions as EC
     from selenium.webdriver.support.wait import WebDriverWait
 except ImportError:
     webdriver = None
@@ -27,6 +34,15 @@ except ImportError:
 rf = RequestFactory()
 
 
+class BuggyPanel(Panel):
+    def title(self):
+        return "BuggyPanel"
+
+    @property
+    def content(self):
+        raise Exception
+
+
 @override_settings(DEBUG=True)
 class DebugToolbarTestCase(BaseTestCase):
     def test_show_toolbar(self):
@@ -86,12 +102,32 @@ class DebugToolbarTestCase(BaseTestCase):
         self.client.get("/cached_view/")
         self.assertEqual(len(self.toolbar.get_panel_by_id("CachePanel").calls), 5)
 
+    def test_is_toolbar_request(self):
+        self.request.path = "/__debug__/render_panel/"
+        self.assertTrue(self.toolbar.is_toolbar_request(self.request))
+
+        self.request.path = "/invalid/__debug__/render_panel/"
+        self.assertFalse(self.toolbar.is_toolbar_request(self.request))
+
+        self.request.path = "/render_panel/"
+        self.assertFalse(self.toolbar.is_toolbar_request(self.request))
+
+    @override_settings(ROOT_URLCONF="tests.urls_invalid")
+    def test_is_toolbar_request_without_djdt_urls(self):
+        """Test cases when the toolbar urls aren't configured."""
+        self.request.path = "/__debug__/render_panel/"
+        self.assertFalse(self.toolbar.is_toolbar_request(self.request))
+
+        self.request.path = "/render_panel/"
+        self.assertFalse(self.toolbar.is_toolbar_request(self.request))
+
 
 @override_settings(DEBUG=True)
-class DebugToolbarIntegrationTestCase(TestCase):
+class DebugToolbarIntegrationTestCase(IntegrationTestCase):
     def test_middleware(self):
         response = self.client.get("/execute_sql/")
         self.assertEqual(response.status_code, 200)
+        self.assertContains(response, "djDebug")
 
     @override_settings(DEFAULT_CHARSET="iso-8859-1")
     def test_non_utf8_charset(self):
@@ -138,6 +174,22 @@ class DebugToolbarIntegrationTestCase(TestCase):
             )
             self.assertEqual(response.status_code, 404)
 
+    def test_middleware_render_toolbar_json(self):
+        """Verify the toolbar is rendered and data is stored for a json request."""
+        self.assertEqual(len(DebugToolbar._store), 0)
+
+        data = {"foo": "bar"}
+        response = self.client.get("/json_view/", data, content_type="application/json")
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(response.content.decode("utf-8"), '{"foo": "bar"}')
+        # Check the history panel's stats to verify the toolbar rendered properly.
+        self.assertEqual(len(DebugToolbar._store), 1)
+        toolbar = list(DebugToolbar._store.values())[0]
+        self.assertEqual(
+            toolbar.get_panel_by_id("HistoryPanel").get_stats()["data"],
+            {"foo": ["bar"]},
+        )
+
     def test_template_source_checks_show_toolbar(self):
         template = get_template("basic.html")
         url = "/__debug__/template_source/"
@@ -161,12 +213,15 @@ class DebugToolbarIntegrationTestCase(TestCase):
     def test_sql_select_checks_show_toolbar(self):
         url = "/__debug__/sql_select/"
         data = {
-            "sql": "SELECT * FROM auth_user",
-            "raw_sql": "SELECT * FROM auth_user",
-            "params": "{}",
-            "alias": "default",
-            "duration": "0",
-            "hash": "6e12daa636b8c9a8be993307135458f90a877606",
+            "signed": SignedDataForm.sign(
+                {
+                    "sql": "SELECT * FROM auth_user",
+                    "raw_sql": "SELECT * FROM auth_user",
+                    "params": "{}",
+                    "alias": "default",
+                    "duration": "0",
+                }
+            )
         }
 
         response = self.client.post(url, data)
@@ -184,12 +239,15 @@ class DebugToolbarIntegrationTestCase(TestCase):
     def test_sql_explain_checks_show_toolbar(self):
         url = "/__debug__/sql_explain/"
         data = {
-            "sql": "SELECT * FROM auth_user",
-            "raw_sql": "SELECT * FROM auth_user",
-            "params": "{}",
-            "alias": "default",
-            "duration": "0",
-            "hash": "6e12daa636b8c9a8be993307135458f90a877606",
+            "signed": SignedDataForm.sign(
+                {
+                    "sql": "SELECT * FROM auth_user",
+                    "raw_sql": "SELECT * FROM auth_user",
+                    "params": "{}",
+                    "alias": "default",
+                    "duration": "0",
+                }
+            )
         }
 
         response = self.client.post(url, data)
@@ -204,15 +262,50 @@ class DebugToolbarIntegrationTestCase(TestCase):
             )
             self.assertEqual(response.status_code, 404)
 
+    @unittest.skipUnless(
+        connection.vendor == "postgresql", "Test valid only on PostgreSQL"
+    )
+    def test_sql_explain_postgres_json_field(self):
+        url = "/__debug__/sql_explain/"
+        base_query = (
+            'SELECT * FROM "tests_postgresjson" WHERE "tests_postgresjson"."field" @>'
+        )
+        query = base_query + """ '{"foo": "bar"}'"""
+        data = {
+            "signed": SignedDataForm.sign(
+                {
+                    "sql": query,
+                    "raw_sql": base_query + " %s",
+                    "params": '["{\\"foo\\": \\"bar\\"}"]',
+                    "alias": "default",
+                    "duration": "0",
+                }
+            )
+        }
+        response = self.client.post(url, data)
+        self.assertEqual(response.status_code, 200)
+        response = self.client.post(url, data, HTTP_X_REQUESTED_WITH="XMLHttpRequest")
+        self.assertEqual(response.status_code, 200)
+        with self.settings(INTERNAL_IPS=[]):
+            response = self.client.post(url, data)
+            self.assertEqual(response.status_code, 404)
+            response = self.client.post(
+                url, data, HTTP_X_REQUESTED_WITH="XMLHttpRequest"
+            )
+            self.assertEqual(response.status_code, 404)
+
     def test_sql_profile_checks_show_toolbar(self):
         url = "/__debug__/sql_profile/"
         data = {
-            "sql": "SELECT * FROM auth_user",
-            "raw_sql": "SELECT * FROM auth_user",
-            "params": "{}",
-            "alias": "default",
-            "duration": "0",
-            "hash": "6e12daa636b8c9a8be993307135458f90a877606",
+            "signed": SignedDataForm.sign(
+                {
+                    "sql": "SELECT * FROM auth_user",
+                    "raw_sql": "SELECT * FROM auth_user",
+                    "params": "{}",
+                    "alias": "default",
+                    "duration": "0",
+                }
+            )
         }
 
         response = self.client.post(url, data)
@@ -245,6 +338,39 @@ class DebugToolbarIntegrationTestCase(TestCase):
         # Link to LOCATION header.
         self.assertIn(b'href="/regular/redirect/"', response.content)
 
+    def test_server_timing_headers(self):
+        response = self.client.get("/execute_sql/")
+        server_timing = response["Server-Timing"]
+        expected_partials = [
+            r'TimerPanel_utime;dur=(\d)*(\.(\d)*)?;desc="User CPU time", ',
+            r'TimerPanel_stime;dur=(\d)*(\.(\d)*)?;desc="System CPU time", ',
+            r'TimerPanel_total;dur=(\d)*(\.(\d)*)?;desc="Total CPU time", ',
+            r'TimerPanel_total_time;dur=(\d)*(\.(\d)*)?;desc="Elapsed time", ',
+            r'SQLPanel_sql_time;dur=(\d)*(\.(\d)*)?;desc="SQL 1 queries", ',
+            r'CachePanel_total_time;dur=0;desc="Cache 0 Calls"',
+        ]
+        for expected in expected_partials:
+            self.assertTrue(re.compile(expected).search(server_timing))
+
+    def test_auth_login_view_without_redirect(self):
+        response = self.client.get("/login_without_redirect/")
+        self.assertEqual(response.status_code, 200)
+        parser = html5lib.HTMLParser()
+        doc = parser.parse(response.content)
+        el = doc.find(".//*[@id='djDebug']")
+        store_id = el.attrib["data-store-id"]
+        response = self.client.get(
+            "/__debug__/render_panel/",
+            {"store_id": store_id, "panel_id": "TemplatesPanel"},
+        )
+        self.assertEqual(response.status_code, 200)
+        # The key None (without quotes) exists in the list of template
+        # variables.
+        if django.VERSION < (3, 0):
+            self.assertIn("None: &#39;&#39;", response.json()["content"])
+        else:
+            self.assertIn("None: &#x27;&#x27;", response.json()["content"])
+
 
 @unittest.skipIf(webdriver is None, "selenium isn't installed")
 @unittest.skipUnless(
@@ -255,15 +381,24 @@ class DebugToolbarLiveTestCase(StaticLiveServerTestCase):
     @classmethod
     def setUpClass(cls):
         super().setUpClass()
-        cls.selenium = webdriver.Firefox()
+        options = Options()
+        options.headless = bool(os.environ.get("CI"))
+        cls.selenium = webdriver.Firefox(options=options)
 
     @classmethod
     def tearDownClass(cls):
         cls.selenium.quit()
         super().tearDownClass()
 
+    def get(self, url):
+        self.selenium.get(self.live_server_url + url)
+
+    @property
+    def wait(self):
+        return WebDriverWait(self.selenium, timeout=3)
+
     def test_basic(self):
-        self.selenium.get(self.live_server_url + "/regular/basic/")
+        self.get("/regular/basic/")
         version_panel = self.selenium.find_element_by_id("VersionsPanel")
 
         # Versions panel isn't loaded
@@ -274,7 +409,7 @@ class DebugToolbarLiveTestCase(StaticLiveServerTestCase):
         self.selenium.find_element_by_class_name("VersionsPanel").click()
 
         # Version panel loads
-        table = WebDriverWait(self.selenium, timeout=10).until(
+        table = self.wait.until(
             lambda selenium: version_panel.find_element_by_tag_name("table")
         )
         self.assertIn("Name", table.text)
@@ -286,31 +421,57 @@ class DebugToolbarLiveTestCase(StaticLiveServerTestCase):
         }
     )
     def test_basic_jinja(self):
-        self.selenium.get(self.live_server_url + "/regular_jinja/basic")
+        self.get("/regular_jinja/basic")
         template_panel = self.selenium.find_element_by_id("TemplatesPanel")
 
         # Click to show the template panel
         self.selenium.find_element_by_class_name("TemplatesPanel").click()
 
-        self.assertIn("Templates (1 rendered)", template_panel.text)
+        self.assertIn("Templates (2 rendered)", template_panel.text)
+        self.assertIn("base.html", template_panel.text)
         self.assertIn("jinja2/basic.jinja", template_panel.text)
 
+    @override_settings(
+        DEBUG_TOOLBAR_CONFIG={
+            "DISABLE_PANELS": {"debug_toolbar.panels.redirects.RedirectsPanel"}
+        }
+    )
+    def test_rerender_on_history_switch(self):
+        self.get("/regular_jinja/basic")
+        # Make a new request so the history panel has more than one option.
+        self.get("/execute_sql/")
+        template_panel = self.selenium.find_element_by_id("HistoryPanel")
+        # Record the current side panel of buttons for later comparison.
+        previous_button_panel = self.selenium.find_element_by_id(
+            "djDebugPanelList"
+        ).text
+
+        # Click to show the history panel
+        self.selenium.find_element_by_class_name("HistoryPanel").click()
+        # Click to switch back to the jinja page view snapshot
+        list(template_panel.find_elements_by_css_selector("button"))[-1].click()
+
+        current_button_panel = self.selenium.find_element_by_id("djDebugPanelList").text
+        # Verify the button side panels have updated.
+        self.assertNotEqual(previous_button_panel, current_button_panel)
+        self.assertNotIn("1 query", current_button_panel)
+        self.assertIn("1 query", previous_button_panel)
+
     @override_settings(DEBUG_TOOLBAR_CONFIG={"RESULTS_CACHE_SIZE": 0})
     def test_expired_store(self):
-        self.selenium.get(self.live_server_url + "/regular/basic/")
+        self.get("/regular/basic/")
         version_panel = self.selenium.find_element_by_id("VersionsPanel")
 
         # Click to show the version panel
         self.selenium.find_element_by_class_name("VersionsPanel").click()
 
         # Version panel doesn't loads
-        error = WebDriverWait(self.selenium, timeout=10).until(
+        error = self.wait.until(
             lambda selenium: version_panel.find_element_by_tag_name("p")
         )
         self.assertIn("Data for this panel isn't available anymore.", error.text)
 
     @override_settings(
-        DEBUG=True,
         TEMPLATES=[
             {
                 "BACKEND": "django.template.backends.django.DjangoTemplates",
@@ -329,85 +490,54 @@ class DebugToolbarLiveTestCase(StaticLiveServerTestCase):
         ],
     )
     def test_django_cached_template_loader(self):
-        self.selenium.get(self.live_server_url + "/regular/basic/")
+        self.get("/regular/basic/")
         version_panel = self.selenium.find_element_by_id("TemplatesPanel")
 
-        # Click to show the versions panel
+        # Click to show the templates panel
         self.selenium.find_element_by_class_name("TemplatesPanel").click()
 
-        # Version panel loads
-        trigger = WebDriverWait(self.selenium, timeout=10).until(
+        # Templates panel loads
+        trigger = self.wait.until(
             lambda selenium: version_panel.find_element_by_css_selector(".remoteCall")
         )
         trigger.click()
 
         # Verify the code is displayed
-        WebDriverWait(self.selenium, timeout=10).until(
+        self.wait.until(
             lambda selenium: self.selenium.find_element_by_css_selector(
                 "#djDebugWindow code"
             )
         )
 
+    def test_sql_action_and_go_back(self):
+        self.get("/execute_sql/")
+        sql_panel = self.selenium.find_element_by_id("SQLPanel")
+        debug_window = self.selenium.find_element_by_id("djDebugWindow")
 
-@override_settings(DEBUG=True)
-class DebugToolbarSystemChecksTestCase(SimpleTestCase):
-    @override_settings(
-        MIDDLEWARE=[
-            "django.contrib.messages.middleware.MessageMiddleware",
-            "django.contrib.sessions.middleware.SessionMiddleware",
-            "django.contrib.auth.middleware.AuthenticationMiddleware",
-            "django.middleware.gzip.GZipMiddleware",
-            "debug_toolbar.middleware.DebugToolbarMiddleware",
-        ]
-    )
-    def test_check_good_configuration(self):
-        messages = run_checks()
-        self.assertEqual(messages, [])
+        # Click to show the SQL panel
+        self.selenium.find_element_by_class_name("SQLPanel").click()
 
-    @override_settings(
-        MIDDLEWARE=[
-            "django.contrib.messages.middleware.MessageMiddleware",
-            "django.contrib.sessions.middleware.SessionMiddleware",
-            "django.contrib.auth.middleware.AuthenticationMiddleware",
-        ]
-    )
-    def test_check_missing_middleware_error(self):
-        messages = run_checks()
-        self.assertEqual(
-            messages,
-            [
-                Warning(
-                    "debug_toolbar.middleware.DebugToolbarMiddleware is "
-                    "missing from MIDDLEWARE.",
-                    hint="Add debug_toolbar.middleware.DebugToolbarMiddleware "
-                    "to MIDDLEWARE.",
-                    id="debug_toolbar.W001",
-                )
-            ],
+        # SQL panel loads
+        button = self.wait.until(
+            EC.visibility_of_element_located((By.CSS_SELECTOR, ".remoteCall"))
         )
+        button.click()
 
-    @override_settings(
-        MIDDLEWARE=[
-            "django.contrib.messages.middleware.MessageMiddleware",
-            "django.contrib.sessions.middleware.SessionMiddleware",
-            "django.contrib.auth.middleware.AuthenticationMiddleware",
-            "debug_toolbar.middleware.DebugToolbarMiddleware",
-            "django.middleware.gzip.GZipMiddleware",
-        ]
-    )
-    def test_check_gzip_middleware_error(self):
-        messages = run_checks()
-        self.assertEqual(
-            messages,
-            [
-                Warning(
-                    "debug_toolbar.middleware.DebugToolbarMiddleware occurs "
-                    "before django.middleware.gzip.GZipMiddleware in "
-                    "MIDDLEWARE.",
-                    hint="Move debug_toolbar.middleware.DebugToolbarMiddleware "
-                    "to after django.middleware.gzip.GZipMiddleware in "
-                    "MIDDLEWARE.",
-                    id="debug_toolbar.W003",
-                )
-            ],
-        )
+        # SQL selected window loads
+        self.wait.until(EC.visibility_of(debug_window))
+        self.assertIn("SQL selected", debug_window.text)
+
+        # Close the SQL selected window
+        debug_window.find_element_by_class_name("djDebugClose").click()
+        self.wait.until(EC.invisibility_of_element(debug_window))
+
+        # SQL panel is still visible
+        self.assertTrue(sql_panel.is_displayed())
+
+    @override_settings(DEBUG_TOOLBAR_PANELS=["tests.test_integration.BuggyPanel"])
+    def test_displays_server_error(self):
+        self.get("/regular/basic/")
+        debug_window = self.selenium.find_element_by_id("djDebugWindow")
+        self.selenium.find_element_by_class_name("BuggyPanel").click()
+        self.wait.until(EC.visibility_of(debug_window))
+        self.assertEqual(debug_window.text, "»\n500: Internal Server Error")
